@@ -29,9 +29,11 @@ FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 """
 
-version_info = (5, 5, 3)
+from packaging.version import parse
 
-__version__ = '.'.join(map(str, version_info))
+version_info = (6, 0, 1)
+
+__version__ = str(parse('.'.join(map(str, version_info))))
 __installer_version__ = __version__
 __title__ = 'Spyder'
 __author__ = 'Spyder Project Contributors and others'
@@ -60,21 +62,18 @@ def get_versions(reporev=True):
 
     import qtpy
     import qtpy.QtCore
+    from spyder_kernels.utils.pythonenv import is_conda_env
 
-    from spyder.utils.conda import is_conda_env
-    from spyder.config.base import is_pynsist, running_in_mac_app
+    from spyder.config.base import is_conda_based_app
 
     revision = branch = None
     if reporev:
-        if running_in_mac_app():
-            revision = os.environ.get('SPY_COMMIT', None)
-            branch = os.environ.get('SPY_BRANCH', None)
-        else:
-            from spyder.utils import vcs
-            revision, branch = vcs.get_git_revision(
-                os.path.dirname(__current_directory__))
+        from spyder.utils import vcs
+        revision, branch = vcs.get_git_revision(
+            os.path.dirname(__current_directory__)
+        )
 
-    if is_pynsist() or running_in_mac_app():
+    if is_conda_based_app():
         installer = 'standalone'
     elif is_conda_env(pyexec=sys.executable):
         installer = 'conda'
