@@ -12,6 +12,7 @@ This file only deals with non-GUI configuration features
 sip API incompatibility issue in spyder's non-gui modules)
 """
 
+from glob import glob
 import locale
 import os
 import os.path as osp
@@ -68,6 +69,14 @@ def running_in_ci_with_conda():
     return running_in_ci() and os.environ.get('USE_CONDA', None) == 'true'
 
 
+def running_in_binder():
+    """Return True if currently running in Binder."""
+    return (
+        bool(os.environ.get("BINDER_REPO_URL"))
+        and "spyder-ide/binder-environments" in os.environ["BINDER_REPO_URL"]
+    )
+
+
 def is_stable_version(version):
     """
     Return true if version is stable, i.e. with letters in the final component.
@@ -341,16 +350,6 @@ def is_py2exe_or_cx_Freeze():
     return osp.isfile(osp.join(get_module_path('spyder'), osp.pardir))
 
 
-def is_pynsist():
-    """Return True if this is a pynsist installation of Spyder."""
-    base_path = osp.abspath(osp.dirname(__file__))
-    pkgs_path = osp.abspath(
-        osp.join(base_path, '..', '..', '..', 'pkgs'))
-    if os.environ.get('PYTHONPATH') is not None:
-        return pkgs_path in os.environ.get('PYTHONPATH')
-    return False
-
-
 #==============================================================================
 # Translations
 #==============================================================================
@@ -377,7 +376,7 @@ LANGUAGE_CODES = {
 }
 
 # Disabled languages because their translations are outdated or incomplete
-DISABLED_LANGUAGES = ['fa', 'hr', 'hu', 'pl', 'te', 'uk']
+DISABLED_LANGUAGES = ['fa', 'hr', 'hu', 'pl', 'te', 'uk', 'ru']
 
 
 def get_available_translations():
@@ -550,61 +549,32 @@ EXCLUDED_NAMES = ['nan', 'inf', 'infty', 'little_endian', 'colorbar_doc',
 
 
 #==============================================================================
-# Mac application utilities
+# Conda-based installer application utilities
 #==============================================================================
-def running_in_mac_app(pyexec=None):
+def is_conda_based_app(pyexec=sys.executable):
     """
-    Check if Python executable is located inside a standalone Mac app.
+    Check if Spyder is running from the conda-based installer by looking for
+    the `spyder-menu.json` file.
 
-    If no executable is provided, the default will check `sys.executable`, i.e.
-    whether Spyder is running from a standalone Mac app.
-
-    This is important for example for the single_instance option and the
-    interpreter status in the statusbar.
+    If a Python executable is provided, checks if it is in a conda-based
+    installer environment or the root environment thereof.
     """
-    if pyexec is None:
-        pyexec = sys.executable
+    real_pyexec = osp.realpath(pyexec)  # pyexec may be symlink
+    if os.name == 'nt':
+        env_path = osp.dirname(real_pyexec)
+    else:
+        env_path = osp.dirname(osp.dirname(real_pyexec))
 
-    bpath = get_mac_app_bundle_path()
-
-    if bpath and pyexec == osp.join(bpath, 'Contents/MacOS/python'):
+    menu_rel_path = '/Menu/conda-based-app'
+    if (
+        osp.exists(env_path + menu_rel_path)
+        or glob(env_path + '/envs/*' + menu_rel_path)
+    ):
         return True
     else:
         return False
 
 
-def get_mac_app_bundle_path():
-    """
-    Return the full path to the macOS app bundle. Otherwise return None.
-
-    EXECUTABLEPATH environment variable only exists if Spyder is a macOS app
-    bundle. In which case it will always end with
-    "/<app name>.app/Conents/MacOS/Spyder".
-    """
-    app_exe_path = os.environ.get('EXECUTABLEPATH', None)
-    if sys.platform == "darwin" and app_exe_path:
-        return osp.dirname(osp.dirname(osp.dirname(osp.abspath(app_exe_path))))
-    else:
-        return None
-
-
-# =============================================================================
-# Micromamba
-# =============================================================================
-def get_spyder_umamba_path():
-    """Return the path to the Micromamba executable bundled with Spyder."""
-    if running_in_mac_app():
-        path = osp.join(osp.dirname(osp.dirname(__file__)),
-                        'bin', 'micromamba')
-    elif is_pynsist():
-        path = osp.abspath(osp.join(osp.dirname(osp.dirname(__file__)),
-                                    'bin', 'micromamba.exe'))
-    else:
-        path = None
-
-    return path
-
-
 #==============================================================================
 # Reset config files
 #==============================================================================
