@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+
 #
 # Copyright © Spyder Project Contributors
 # Licensed under the terms of the MIT License
@@ -16,7 +17,6 @@ import sys
 
 # Local import
 from spyder.config.base import CHECK_ALL, EXCLUDED_NAMES
-from spyder.config.fonts import MEDIUM, SANS_SERIF
 from spyder.config.utils import IMPORT_EXT
 from spyder.config.appearance import APPEARANCE
 from spyder.plugins.editor.utils.findtasks import TASKS_PATTERN
@@ -75,17 +75,20 @@ DEFAULTS = [
               'window/position': (10, 10),
               'window/is_maximized': True,
               'window/is_fullscreen': False,
-              'window/prefs_dialog_size': (1050, 530),
               'use_custom_margin': True,
               'custom_margin': 0,
               'use_custom_cursor_blinking': False,
               'show_internal_errors': True,
-              'check_updates_on_startup': True,
               'cursor/width': 2,
               'completion/size': (300, 180),
               'report_error/remember_token': False,
               'show_dpi_message': True,
               }),
+            ('update_manager',
+             {
+              'check_updates_on_startup': True,
+              'check_stable_only': True,
+              }),
             ('toolbar',
              {
               'enable': True,
@@ -102,6 +105,10 @@ DEFAULTS = [
               'clock/enable': False,
               'clock/timeout': 1000,
               }),
+            ('pythonpath_manager',
+             {
+              'spyder_pythonpath': [],
+              }),
             ('quick_layouts',
              {
               'place_holder': '',
@@ -129,6 +136,7 @@ DEFAULTS = [
               'umr/namelist': [],
               'custom_interpreters_list': [],
               'custom_interpreter': '',
+              'last_envs': {}
               }),
             ('ipython_console',
              {
@@ -140,11 +148,13 @@ DEFAULTS = [
               'buffer_size': 500,
               'pylab': True,
               'pylab/autoload': False,
-              'pylab/backend': 0,
-              'pylab/inline/figure_format': 0,
-              'pylab/inline/resolution': 72,
+              'pylab/backend': 'inline',
+              'pylab/inline/figure_format': 'png',
+              'pylab/inline/resolution': 144,
               'pylab/inline/width': 6,
               'pylab/inline/height': 4,
+              'pylab/inline/fontsize': 10.0,
+              'pylab/inline/bottom': 0.11,
               'pylab/inline/bbox_inches': True,
               'startup/run_lines': '',
               'startup/use_run_file': False,
@@ -152,6 +162,7 @@ DEFAULTS = [
               'greedy_completer': False,
               'jedi_completer': False,
               'autocall': 0,
+              'autoreload': True,
               'symbolic_math': False,
               'in_prompt': '',
               'out_prompt': '',
@@ -161,11 +172,6 @@ DEFAULTS = [
               # that generate a lot of Command Prompts while running,
               # and that's extremely annoying for Windows users.
               'hide_cmd_windows': True,
-              'pdb_prevent_closing': True,
-              'pdb_ignore_lib': False,
-              'pdb_execute_events': True,
-              'pdb_use_exclamation_mark': True,
-              'pdb_stop_first_line': True
               }),
             ('variable_explorer',
              {
@@ -181,20 +187,32 @@ DEFAULTS = [
               'truncate': True,
               'minmax': False,
               'show_callable_attributes': True,
-              'show_special_attributes': False
+              'show_special_attributes': False,
+              'filter_on': True
+             }),
+            ('debugger',
+             {
+              'exclude_internal': True,
+              'pdb_prevent_closing': True,
+              'pdb_ignore_lib': False,
+              'pdb_execute_events': True,
+              'pdb_use_exclamation_mark': True,
+              'pdb_stop_first_line': True,
+              'editor_debugger_panel': True,
+              'breakpoints_table_visible': False,
+             }),
+            ('run',
+             {
+              'save_all_before_run': True,
+              'run_cell_copy': False,
              }),
             ('plots',
              {
               'mute_inline_plotting': True,
               'show_plot_outline': False,
-              'auto_fit_plotting': True
              }),
             ('editor',
              {
-              'printer_header/font/family': SANS_SERIF,
-              'printer_header/font/size': MEDIUM,
-              'printer_header/font/italic': False,
-              'printer_header/font/bold': False,
               'wrap': False,
               'wrapflag': True,
               'todo_list': True,
@@ -222,8 +240,7 @@ DEFAULTS = [
               'tab_always_indent': False,
               'intelligent_backspace': True,
               'automatic_completions': True,
-              'automatic_completions_after_chars': 3,
-              'automatic_completions_after_ms': 300,
+              'automatic_completions_after_chars': 1,
               'completions_hint': True,
               'completions_hint_after_ms': 500,
               'underline_errors': False,
@@ -237,14 +254,12 @@ DEFAULTS = [
               'show_tab_bar': True,
               'show_class_func_dropdown': False,
               'max_recent_files': 20,
-              'save_all_before_run': True,
-              'focus_to_editor': True,
-              'run_cell_copy': False,
               'onsave_analysis': False,
               'autosave_enabled': True,
               'autosave_interval': 60,
               'docstring_type': 'Numpydoc',
               'strip_trailing_spaces_on_modify': False,
+              'show_outline_in_editor_window': True,
               }),
             ('historylog',
              {
@@ -283,7 +298,15 @@ DEFAULTS = [
               'sort_files_alphabetically': False,
               'show_comments': True,
               'follow_cursor': True,
-              'display_variables': False
+              'display_variables': False,
+              'show_with_maximized_editor': True,
+              }),
+            ('preferences',
+             {
+              'enable': True,
+              'dialog_size': (
+                  (1010, 725) if MAC else ((900, 670) if WIN else (950, 690))
+              ),
               }),
             ('project_explorer',
              {
@@ -323,10 +346,6 @@ DEFAULTS = [
               'exclude_case_sensitive': False,
               'max_results': 1000,
               }),
-            ('breakpoints',
-             {
-              'enable': True,
-              }),
             ('completions',
              {
                'enable': True,
@@ -349,7 +368,6 @@ DEFAULTS = [
               }),
             ('workingdir',
              {
-              'working_dir_adjusttocontents': False,
               'working_dir_history': 20,
               'console/use_project_or_home_directory': False,
               'console/use_cwd': True,
@@ -364,8 +382,7 @@ DEFAULTS = [
              }),
             ('shortcuts',
              {
-              # ---- Global ----
-              # -- In app/spyder.py
+              # -- Application --
               '_/close pane': "Shift+Ctrl+F4",
               '_/lock unlock panes': "Shift+Ctrl+F5",
               '_/use next layout': "Shift+Alt+PgDown",
@@ -377,24 +394,15 @@ DEFAULTS = [
               '_/spyder documentation': "F1",
               '_/restart': "Shift+Alt+R",
               '_/quit': "Ctrl+Q",
-              # -- In plugins/editor
-              '_/file switcher': 'Ctrl+P',
-              '_/symbol finder': 'Ctrl+Alt+P',
-              '_/debug': "Ctrl+F5",
-              '_/debug step over': "Ctrl+F10",
-              '_/debug continue': "Ctrl+F12",
-              '_/debug step into': "Ctrl+F11",
-              '_/debug step return': "Ctrl+Shift+F11",
-              '_/debug exit': "Ctrl+Shift+F12",
               '_/run': "F5",
               '_/configure': "Ctrl+F6",
               '_/re-run last script': "F6",
-              # -- In plugins/init
+              # -- Switch to plugin --
               '_/switch to help': "Ctrl+Shift+H",
               '_/switch to outline_explorer': "Ctrl+Shift+O",
               '_/switch to editor': "Ctrl+Shift+E",
               '_/switch to historylog': "Ctrl+Shift+L",
-              '_/switch to onlinehelp': "Ctrl+Shift+D",
+              '_/switch to onlinehelp': "",
               '_/switch to project_explorer': "Ctrl+Shift+P",
               '_/switch to ipython_console': "Ctrl+Shift+I",
               '_/switch to variable_explorer': "Ctrl+Shift+V",
@@ -403,15 +411,15 @@ DEFAULTS = [
               '_/switch to plots': "Ctrl+Shift+J" if MAC else "Ctrl+Shift+G",
               '_/switch to pylint': "Ctrl+Shift+C",
               '_/switch to profiler': "Ctrl+Shift+R",
-              # -- In widgets/findreplace.py
+              '_/switch to debugger': "Ctrl+Shift+D",
+              # -- Find/replace --
               'find_replace/find text': "Ctrl+F",
               'find_replace/find next': "Ctrl+G" if MAC else "F3",
               'find_replace/find previous': (
                   "Ctrl+Shift+G" if MAC else "Shift+F3"),
               'find_replace/replace text': "Ctrl+R",
               'find_replace/hide find and replace': "Escape",
-              # ---- Editor ----
-              # -- In widgets/sourcecode/codeeditor.py
+              # -- Editor --
               'editor/code completion': CTRL+'+Space',
               'editor/duplicate line up': (
                   "Ctrl+Alt+Up" if WIN else "Shift+Alt+Up"),
@@ -427,6 +435,7 @@ DEFAULTS = [
               'editor/go to new line': "Ctrl+Shift+Return",
               'editor/go to definition': "F3" if MAC else "Ctrl+G",
               'editor/toggle comment': "Ctrl+1",
+              'editor/create_new_cell': "Ctrl+2",
               'editor/blockcomment': "Ctrl+4",
               'editor/unblockcomment': "Ctrl+5",
               'editor/start of line': "Meta+A",
@@ -452,13 +461,7 @@ DEFAULTS = [
               'editor/paste': 'Ctrl+V',
               'editor/delete': 'Del',
               'editor/select all': "Ctrl+A",
-              # -- In widgets/editor.py
               'editor/inspect current object': 'Ctrl+I',
-              'editor/breakpoint': 'F12',
-              'editor/conditional breakpoint': 'Shift+F12',
-              'editor/run selection': "F9",
-              'editor/run to line': 'Shift+F9',
-              'editor/run from line': CTRL + '+F9',
               'editor/go to line': 'Ctrl+L',
               'editor/go to previous file': CTRL + '+Shift+Tab',
               'editor/go to next file': CTRL + '+Tab',
@@ -484,27 +487,36 @@ DEFAULTS = [
               'editor/close file 2': "Ctrl+F4",
               'editor/run cell': CTRL + '+Return',
               'editor/run cell and advance': 'Shift+Return',
-              'editor/debug cell': 'Alt+Shift+Return',
+              'editor/run selection and advance': "F9",
+              'editor/run selection up to line': 'Shift+F9',
+              'editor/run selection from line': 'Alt+F9',
               'editor/go to next cell': 'Ctrl+Down',
               'editor/go to previous cell': 'Ctrl+Up',
-              'editor/re-run last cell': 'Alt+Return',
+              'editor/re-run cell': 'Alt+Return',
+              'editor/scroll line down': '',
+              'editor/scroll line up': '',
               'editor/split vertically': "Ctrl+{",
               'editor/split horizontally': "Ctrl+_",
               'editor/close split panel': "Alt+Shift+W",
               'editor/docstring': "Ctrl+Alt+D",
               'editor/autoformatting': "Ctrl+Alt+I",
               'editor/show in external file explorer': '',
-              # -- In Breakpoints
-              '_/switch to breakpoints': "Ctrl+Shift+B",
-              # ---- Consoles (in widgets/shell) ----
-              'console/inspect current object': "Ctrl+I",
-              'console/clear shell': "Ctrl+L",
-              'console/clear line': "Shift+Escape",
-              # ---- In Pylint ----
-              'pylint/run analysis': "F8",
-              # ---- In Profiler ----
-              'profiler/run profiler': "F10",
-              # ---- In widgets/ipythonconsole/shell.py ----
+              'editor/enter array inline': "Ctrl+Alt+M",
+              'editor/enter array table': "Ctrl+M",
+              'editor/run cell in debugger': 'Alt+Shift+Return',
+              'editor/run selection in debugger': CTRL + '+F9',
+              # -- Internal console --
+              'internal_console/inspect current object': "Ctrl+I",
+              'internal_console/clear shell': "Ctrl+L",
+              'internal_console/clear line': "Shift+Escape",
+              # -- Pylint --
+              'pylint/run file in pylint': "F8",
+              # -- Profiler --
+              'profiler/run file in profiler': "F10",
+              # -- Switcher --
+              'switcher/file switcher': 'Ctrl+P',
+              'switcher/symbol finder': 'Ctrl+Alt+P',
+              # -- IPython console --
               'ipython_console/new tab': "Ctrl+T",
               'ipython_console/reset namespace': "Ctrl+Alt+R",
               'ipython_console/restart kernel': "Ctrl+.",
@@ -513,30 +525,44 @@ DEFAULTS = [
               'ipython_console/clear line': "Shift+Escape",
               'ipython_console/enter array inline': "Ctrl+Alt+M",
               'ipython_console/enter array table': "Ctrl+M",
-              # ---- In widgets/arraybuider.py ----
-              'array_builder/enter array inline': "Ctrl+Alt+M",
-              'array_builder/enter array table': "Ctrl+M",
-              # ---- In widgets/variableexplorer/arrayeditor.py ----
+              # -- Variable explorer --
               'variable_explorer/copy': 'Ctrl+C',
-              # ---- In widgets/variableexplorer/namespacebrowser.py ----
               'variable_explorer/search': 'Ctrl+F',
               'variable_explorer/refresh': 'Ctrl+R',
-              # ---- In widgets/plots/figurebrowser.py ----
+              # -- Debugger --
+              'debugger/refresh': 'Ctrl+R',
+              'debugger/search': 'Ctrl+F',
+              'debugger/run file in debugger': "Ctrl+F5",
+              'debugger/next': "Ctrl+F10",
+              'debugger/continue': "Ctrl+F12",
+              'debugger/step': "Ctrl+F11",
+              'debugger/return': "Ctrl+Shift+F11",
+              'debugger/stop': "Ctrl+Shift+F12",
+              'debugger/toggle breakpoint': 'F12',
+              'debugger/toggle conditional breakpoint': 'Shift+F12',
+              'debugger/show breakpoint table': "",
+              # -- Plots --
               'plots/copy': 'Ctrl+C',
               'plots/previous figure': 'Ctrl+PgUp',
               'plots/next figure': 'Ctrl+PgDown',
               'plots/save': 'Ctrl+S',
-              'plots/save all': 'Ctrl+Alt+S',
+              'plots/save all': 'Alt+Shift+S',
               'plots/close': 'Ctrl+W',
-              'plots/close all': 'Ctrl+Shift+W',
+              'plots/close all': 'Alt+Shift+W',
               'plots/zoom in': "Ctrl++",
               'plots/zoom out': "Ctrl+-",
-              # ---- In widgets/explorer ----
+              'plots/auto fit': "Ctrl+0",
+              # -- Files --
               'explorer/copy file': 'Ctrl+C',
               'explorer/paste file': 'Ctrl+V',
-              'explorer/copy absolute path': 'Ctrl+Alt+C',
-              'explorer/copy relative path': 'Ctrl+Alt+Shift+C',
-              # ---- In plugins/findinfiles/plugin ----
+              'explorer/copy absolute path': 'Alt+Shift+C',
+              'explorer/copy relative path': 'Alt+Shift+D',
+              # -- Projects --
+              'project_explorer/copy file': 'Ctrl+C',
+              'project_explorer/paste file': 'Ctrl+V',
+              'project_explorer/copy absolute path': 'Alt+Shift+C',
+              'project_explorer/copy relative path': 'Alt+Shift+D',
+              # -- Find --
               'find_in_files/find in files': 'Alt+Shift+F',
               }),
             ('appearance', APPEARANCE),
@@ -556,9 +582,7 @@ NAME_MAP = {
             'crash',
             'current_version',
             'historylog_filename',
-            'spyder_pythonpath',
             'window/position',
-            'window/prefs_dialog_size',
             'window/size',
             'window/state',
             ]
@@ -574,6 +598,7 @@ NAME_MAP = {
             'layout_settings',
             'recent_files',
             'splitter_state',
+            'file_uuids'
             ]
          ),
         ('explorer', [
@@ -590,6 +615,7 @@ NAME_MAP = {
             'custom_interpreters_list',
             'custom_interpreter',
             'executable',
+            'last_envs',
              ]
          ),
         ('onlinehelp', [
@@ -601,6 +627,10 @@ NAME_MAP = {
             'scrollbar_position',
             ],
          ),
+        ('preferences', [
+            'dialog_size',
+            ],
+         ),
         ('project_explorer', [
             'current_project_path',
             'expanded_state',
@@ -609,12 +639,14 @@ NAME_MAP = {
             'scrollbar_position',
           ]
          ),
+        ('pythonpath_manager', []),
         ('quick_layouts', []), # Empty list means use all options
         ('run', [
             'breakpoints',
             'configurations',
-            'defaultconfiguration',
             'default/wdir/fixed_directory',
+            'last_used_parameters',
+            'parameters'
           ]
          ),
         ('workingdir', [
@@ -631,7 +663,7 @@ NAME_MAP = {
 
 
 # =============================================================================
-# Config instance
+# Config version
 # =============================================================================
 # IMPORTANT NOTES:
 # 1. If you want to *change* the default value of a current option, you need to
@@ -640,4 +672,4 @@ NAME_MAP = {
 #    or if you want to *rename* options, then you need to do a MAJOR update in
 #    version, e.g. from 3.0.0 to 4.0.0
 # 3. You don't need to touch this value if you're just adding a new option
-CONF_VERSION = '71.1.0'
+CONF_VERSION = '84.2.0'
